==> restful-1.36.23-Final-sources.jar: com/aote/redis/RedisService.java <==
package com.aote.redis;

import org.json.JSONObject;

import java.util.Map;

/**
 * Redis业务接口
 */
public interface RedisService {

    /**
     * 存储一条key/value数据
     * @param key 数据key
     * @param value 数据value
     */
    void set(String key, Object value);

    /**
     * 存储一条key/value数据（带过期时间）
     * @param key 数据key
     * @param value 数据value
     * @param timeoutSec 过期时间(秒)
     */
    void set(String key, Object value, Integer timeoutSec);

    /**
     * 存储一条hash数据
     * @param hashKey hashKey
     * @param value jsonObject对象
     */
    void setHash(String hashKey, JSONObject value);

    /**
     * 存储一条hash数据
     * @param hashKey hashKey
     * @param value map对象
     * @param timeoutSec 超时时间
     */
    void setHash(String hashKey, Map<String, Object> value, Integer timeoutSec);
    void setHash(String hashKey, Map<String, Object> value);

    /**
     * 获取一条json格式的hash数据
     * @param hashKey hashKey
     * @return jsonObject对象
     */
    JSONObject getHash(String hashKey);

    /**
     * 获取指定hash中key的数据
     * @param hashKey hashKey
     * @param key 数据key
     * @return 数据value
     */
    Object getHash(String hashKey,String key);

    /**
     * 向指定hash中存储一条key/value数据
     * @param hashKey hashKey
     * @param key 数据key
     * @param value 数据value
     */
    void setHashKey(String hashKey,String key,Object value);

    /**
     * 删除指定hash中key的数据
     * @param hashKey hashKey
     * @param key 数据key
     */
    void deleteHashKey(String hashKey,String key);

    /**
     * 判断指定hash中是否含有该key的数据
     * @param hashKey hashKey
     * @param key 数据key
     */
    Boolean hasHashKey(String hashKey,String key);

    /**
     * 获取一条key/value数据
     * @param key 数据key
     * @return 数据value
     */
    Object get(String key);

    /**
     * 删除一条key/value数据
     * @param key 数据key
     */
    void delete(String key);

    /**
     * 批量删除指定key集合的数据
     * @param keys 数据key集合
     */
    void deleteList(Iterable<Object> keys);
    void deleteList(JSONObject keys);

    /**
     * 获取锁
     * @param key 需要获取锁的key
     * @param runnable 执行的函数
     */
    void lock(String key, RedisUtil.Runnable runnable);
}

==> restful-1.37.1-Final-sources.jar: com/aote/redis/RedisService.java <==
package com.aote.redis;

import org.json.JSONObject;

import java.util.Map;

/**
 * Redis业务接口
 */
public interface RedisService {

    /**
     * 存储一条key/value数据
     * @param key 数据key
     * @param value 数据value
     */
    void set(String key, Object value);

    /**
     * 存储一条key/value数据（带过期时间）
     * @param key 数据key
     * @param value 数据value
     * @param timeoutSec 过期时间(秒)
     */
    void set(String key, Object value, long timeoutSec);

    /**
     * 存储一条hash数据
     * @param hashKey hashKey
     * @param value jsonObject对象
     */
    void setHash(String hashKey, JSONObject value);

    /**
     * 存储一条hash数据
     * @param hashKey hashKey
     * @param value map对象
     * @param timeoutSec 超时时间
     */
    void setHash(String hashKey, Map<String, Object> value, long timeoutSec);
    void setHash(String hashKey, Map<String, Object> value);

    /**
     * 获取一条json格式的hash数据
     * @param hashKey hashKey
     * @return jsonObject对象
     */
    JSONObject getHash(String hashKey);

    /**
     * 获取指定hash中key的数据
     * @param hashKey hashKey
     * @param key 数据key
     * @return 数据value
     */
    Object getHash(String hashKey,String key);

    /**
     * 向指定hash中存储一条key/value数据
     * @param hashKey hashKey
     * @param key 数据key
     * @param value 数据value
     */
    void setHashKey(String hashKey,String key,Object value);

    /**
     * 删除指定hash中key的数据
     * @param hashKey hashKey
     * @param key 数据key
     */
    void deleteHashKey(String hashKey,String key);

    /**
     * 判断指定hash中是否含有该key的数据
     * @param hashKey hashKey
     * @param key 数据key
     */
    Boolean hasHashKey(String hashKey,String key);

    /**
     * 获取一条key/value数据
     * @param key 数据key
     * @return 数据value
     */
    Object get(String key);

    /**
     * 删除一条key/value数据
     * @param key 数据key
     */
    void delete(String key);

    /**
     * 批量删除指定key集合的数据
     * @param keys 数据key集合
     */
    void deleteList(Iterable<Object> keys);
    void deleteList(JSONObject keys);

    /**
     * 获取锁
     * @param key 需要获取锁的key
     * @param runnable 执行的函数
     */
    void lock(String key, RedisUtil.Runnable runnable);
}
